@@ -2,7 +2,7 @@
 from pathlib import Path
 
 __author__ = "Matthias Koenig"
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 
 from depinfo import print_dependencies  # type: ignore
@@ -16,5 +16,5 @@ def show_versions() -> None:
 program_name: str = "pymetadata"
 RESOURCES_DIR: Path = Path(__file__).parent / "resources"
 
-CACHE_USE: bool = True
+CACHE_USE: bool = False
 CACHE_PATH: Path = RESOURCES_DIR / "cache"
